==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/DTPInputStream.h <==
// abstract class gnu.java.net.protocol.ftp.DTPInputStream

// class file dependencies
// @dep_class d85c82adc9496692 gnu_java_net_protocol_ftp_DTPInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_DTPInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_DTPInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$refs	_jc_gnu_java_net_protocol_ftp_DTPInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_DTPInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object	_jc_gnu_java_net_protocol_ftp_DTPInputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtable	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_DTPInputStream$method$_init$6ecf86878bba3fe8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *, struct _jc_object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_DTPInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *);
extern void _jc_gnu_java_net_protocol_ftp_DTPInputStream$method$setTransferComplete$cd2138d5d98b31f0(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_DTPInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_protocol_ftp_DTPInputStream$method_info$setTransferComplete$cd2138d5d98b31f0;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *);
	void	(*setTransferComplete$cd2138d5d98b31f0)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *, jboolean);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	gnu_java_net_protocol_ftp_DTPInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs {
	struct _jc_object	*dtp;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs {
	jboolean	transferComplete;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object {
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype _jc_gnu_java_net_protocol_ftp_DTPInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_DTPInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_DTPInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_DTPInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/DTPInputStream.h <==
// abstract class gnu.java.net.protocol.ftp.DTPInputStream

// class file dependencies
// @dep_class d85c82adc9496692 gnu_java_net_protocol_ftp_DTPInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_DTPInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_DTPInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTP$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$refs	_jc_gnu_java_net_protocol_ftp_DTPInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_DTPInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object	_jc_gnu_java_net_protocol_ftp_DTPInputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtable	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_DTPInputStream$method$_init$6ecf86878bba3fe8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *, struct _jc_object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_DTPInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_DTPInputStream$method$setTransferComplete$cd2138d5d98b31f0(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_DTPInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_protocol_ftp_DTPInputStream$method_info$setTransferComplete$cd2138d5d98b31f0;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *) _JC_JCNI_ATTR;
	void	(*setTransferComplete$cd2138d5d98b31f0)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vmethods	gnu_java_net_protocol_ftp_DTPInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs {
	struct _jc_object	*dtp;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_refs	gnu_java_net_protocol_ftp_DTPInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs {
	jboolean	transferComplete;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_DTPInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_DTPInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object {
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_DTPInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_DTPInputStream$vtype _jc_gnu_java_net_protocol_ftp_DTPInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_DTPInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_DTPInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_DTPInputStream_H_ */
